#ifndef hs_READER_H
#define hs_READER_H 

#ifdef WIN32
#include <winsock2.h>
#pragma comment(lib, "ws2_32.lib")
#define USER_API __stdcall
#else
typedef int HANDLE;
#define USER_API
#endif



#define ZBCR_VERSION     "1.3.10"

#define ZBCR_API    __stdcall

#ifdef __cplusplus
extern "C" {
#endif
typedef int  ZBCR_STATUS ;



typedef void (ZBCR_API *CALL_BACK_DATA)(unsigned char *data,unsigned int length, unsigned long userdata);

typedef struct portParam
{
    short portNo;
    unsigned long baudRate;
}PortParam;


/*
    打开设备端口
    @param
        pParam  指向端口PortParam数据的指针. 
                NULL 自动连接扫描设备
                不为空 portNo
                    0 - 1000 串口号 
                    1100     HID端口
                    -1       自动连接扫描设备
                    -2       自动连接串口,轮询所有串口
    @return  
            ZBCR_SUCCESS    打开成功
            ZBCR_INIT_FAIL  打开失败
*/
ZBCR_STATUS ZBCR_API ZBCR_Open(void* pParam, 
                               CALL_BACK_DATA pfnReadData,
                               unsigned long userdata);

/*
    打开设备端口
    @param
        portNo  
                0 - 1000 串口号 
                1100     HID端口
                -1       自动连接扫描设备
                -2       自动连接串口,轮询所有串口
        baudRate
                串口波特率
        pfnReadData
                解码回调函数指针
        userdata
                用户数据句柄等，回调函数传入
    @return  
            ZBCR_SUCCESS    打开成功
            ZBCR_INIT_FAIL  打开失败
*/
ZBCR_STATUS ZBCR_API ZBCR_Open2(short portNo, 
                                long baudRate, 
                                CALL_BACK_DATA pfnReadData,
                                unsigned long userdata);
/*
    打开设备端口
    @param
        portNo  
                0 - 1000 串口号 
                1100     HID端口
                -1       自动连接串口设备
        pReadWideCharData
                解码回调函数地址
                typedef void (__stdcall *ReadDataCallBack)(BSTR data, int len, unsigned long userdata);
        userdata
                用户数据句柄等，回调函数传入
    @return  
            ZBCR_SUCCESS    打开成功
            ZBCR_INIT_FAIL  打开失败
*/
ZBCR_STATUS ZBCR_API ZBCR_Open3(short portNo, 
                                          long baudRate, 
                                          long pReadWideCharData,
                                          unsigned long userdata);

ZBCR_STATUS ZBCR_API ZBCR_Close(void);


ZBCR_STATUS ZBCR_API ZBCR_GetApiVersion(char* ver_str);

ZBCR_STATUS ZBCR_API ZBCR_StartScan();
ZBCR_STATUS ZBCR_API ZBCR_StopScan();

// totalTimeOunt = nTimeOut*100ms
ZBCR_STATUS ZBCR_API ZBCR_ReadDecode(unsigned short nTimeOut,
							unsigned char* pOutputBuffer, 
                            unsigned int nSizeOfOutputBuffer,
                            unsigned int *pnBytesReturned);



ZBCR_STATUS ZBCR_API ZBCR_SetupRead(unsigned char* pInputBuffer,
									    unsigned int nBytesInInputBuffer,
									    unsigned char *pOutputBuffer, 
								        unsigned int nSizeOfOutputBuffer, 
								        unsigned int *pnBytesReturned);


ZBCR_STATUS ZBCR_API ZBCR_SetupWrite(unsigned char* pInputBuffer,
									     unsigned int nBytesInInputBuffer,
									     unsigned char *pOutputBuffer, 
									     unsigned int nSizeOfOutputBuffer, 
                                         unsigned int *pnBytesReturned);


ZBCR_STATUS ZBCR_API ZBCR_ControlCmd (
									  unsigned char *pInputBuffer,
									  unsigned int nBytesInInputBuffer,
									  unsigned char *pOutputBuffer,
									  unsigned int nSizeOfOutputBuffer,
                                      unsigned int *pnBytesReturned);


ZBCR_STATUS ZBCR_API ZBCR_StatusRead(unsigned char* pInputBuffer,
									   unsigned int nBytesInInputBuffer,
									   unsigned char *pOutputBuffer, 
									   unsigned int nSizeOfOutputBuffer, 
									   unsigned int *pnBytesReturned);
//大象发票查验定制交互接口 ZBCR_CTax

ZBCR_STATUS ZBCR_CTax (
                                      unsigned char *pInputBuffer,
                                      unsigned int nBytesInInputBuffer,
                                      unsigned char *pOutputBuffer,
                                      unsigned int nSizeOfOutputBuffer,
                                      unsigned int *pnBytesReturned);
/*
  获取最后一张图像数据大小，可用于分配存储图像数据空间

  @param
  @return  
            > 0 图像数据大小
            -1  获取失败
*/
int  ZBCR_API ZBCR_GetLastImageSize(void);

/*
  获取最后一张图像数据

  @param
            image_data  图像数据缓存指针，指向缓存空间，不可为空
            imagesize   [输入] 缓存空间大小 [输出] 实际获取到的数据大小，不可为空
            image_w     图像宽度
            image_h     图像高度
  @return  
            ZBCR_SUCCESS    获取成功
            其他错误值      获取失败
*/
ZBCR_STATUS  ZBCR_API ZBCR_GetLastImage(unsigned char* image_data, int* imagesize, int* image_w, int* image_h);


ZBCR_STATUS ZBCR_API ZBCR_Led(unsigned int setNo);
ZBCR_STATUS ZBCR_API ZBCR_LocationLed(unsigned int setNo);

#define SCAN_MODE_LEVEL           0x00 //按键按下开始解码，松开按键或解码成功停止解码
#define SCAN_MODE_TOGGLE          0x01 //按键按下开始解码，再次按键按下停止解码
#define SCAN_MODE_AUTO            0x02 //上电后一直解码
#define SCAN_MODE_SENSOR          0x03 //感应解码，上电后开始检测是否有条码，当有条码出现则解码
#define SCAN_MODE_PULSE           0x04 //波动解码，按键按下开始解码，直到达到超时时间或解码成功停止解码
#define SCAN_MODE_MOTION_SENSOR   0x05 //扫描装置固定，图像中物体移动感应解码
ZBCR_STATUS ZBCR_API ZBCR_ScanMode(unsigned int mode);

#ifdef __cplusplus
}
#endif




#define ZBCR_FALL                     0   //返回失败
#define ZBCR_SUCCESS                  1   //返回成功
#define ZBCR_WRITE_ERROR             -1   //设备写失败
#define ZBCR_READ_TIMEOUT            -2   //读超时
#define ZBCR_READ_ERROR              -3   //读失败
#define ZBCR_INIT_FAIL               -4   //设备初始化失败
#define ZBCR_DEVICE_NOT_FOUND        -5   //设备未找到
#define ZBCR_DEVICE_BUSY             -6   //设备忙碌中
#define ZBCR_ILLEGAL_REPLY           -7   //设备非法应答	
#define ZBCR_DEVICE_IO_FAILED        -8   //通讯异常
#define ZBCR_OUT_OF_SIZE             -9
#define ZBCR_PARAM_POINT_NULL       -10 //参数指针为空





#ifdef __cplusplus
extern "C" {
#endif
/**
* @brief  获取扫码结果。
* @par    说明：
* 获取扫码结果前必须保证该端口资源是空闲的即如激活了读卡功能的话确保已经调用的了hs_exit
* @param[in] data 扫码结果
* @param[in] milliseconds 每次的超时时间，建议300，只有扫到码或者按esc接口才会退出
* @return <0表示失败，=0 位成功
*/
int USER_API  hs_GetQrcode(unsigned char *data, int milliseconds);
/**
* @brief  获取序列号
* @par    说明：
* 获取扫码结果前必须保证该端口资源是空闲的即如激活了读卡功能的话确保已经调用的了hs_exit
* @param[in] SNnumber 序列号
* @return <0表示失败，=0 为成功
*/
int USER_API  hs_GetSNCode(char *SNnumber);

/**
   * @brief 获取设备序列号
   */
short USER_API hs_getrcinfo(HANDLE icdev, unsigned char *info);
 /**
   * @brief   获取设备序列号
 */
short USER_API hs_getrcinfo_hex(HANDLE icdev, unsigned char *info);


/**
* @brief  获取扫码结果。
* @par    说明：
* 获取扫码结果前必须保证该端口资源是空闲的即如激活了读卡功能的话确保已经调用的了hs_exit
* @param[in] data 扫码结果
* @param[in] milliseconds 超时时间
* @return <0表示失败，=0 位成功
*/
int USER_API  hs_GetQrcodetimeout(unsigned char *data, int milliseconds);

/**
* @brief  打开扫码设备启动回调接口。
* @par    说明：
* 获取扫码结果前必须保证该端口资源是空闲的即如激活了读卡功能的话确保已经调用的了hs_exit
* @param[in] pfnReadData 扫码结果回通过次回调函数显示
* @return <0表示失败，=0 位成功
*/

int USER_API  hs_OpenQrcode(CALL_BACK_DATA pfnReadData);
/**
* @brief  关闭扫码设备。
* @par    说明：
* 获取扫码结果前必须保证该端口资源是空闲的即如激活了读卡功能的话确保已经调用的了hs_exit

*/

void USER_API  hs_CloseQrcode(void);
/**
* @brief  打开设备。
* @par    说明：
* 建立设备的通讯并且分配相应的资源，大部分功能接口都需要在此过程后才能进行，在不需要使用设备后，必须使用 ::hs_exit 去关闭设备的通讯和释放资源。
* @param[in] port 端口号。
* @n 1~99 - 表示串口模式（编号物理对应），编号1表示第一个串口合法设备，编号2表示第二个串口合法设备，以此类推。
* @n 100~199 - 表示USB模式（编号逻辑对应），编号100表示第一个USB合法设备，编号1表示第二个USB合法设备，以此类推。
* @n 200~299 - 表示PCSC模式（编号逻辑对应），编号200表示第一个PCSC合法设备，编号201表示第二个PCSC合法设备，以此类推。
* @n 300~399 - 表示蓝牙模式（编号逻辑对应），编号300表示第一个蓝牙合法设备，编号301表示第二个蓝牙合法设备，以此类推。
* @param[in] baud 波特率，只针对串口模式有效。
* @return <0表示失败，否则为设备标识符。 -22端口错误 合法值1-99 -10版本错误 
*/
HANDLE USER_API hs_init(short port, int baud);

/**
* @brief  打开设备。
* @par    说明：
* 建立设备的通讯并且分配相应的资源，大部分功能接口都需要在此过程后才能进行，在不需要使用设备后，必须使用 ::hs_exit 去关闭设备的通讯和释放资源。
* @param[in] port 端口号。
* @n 0~99 - 表示串口模式（编号物理对应），编号0表示第一个串口合法设备，编号1表示第二个串口合法设备，以此类推。
* @n 100~199 - 表示USB模式（编号逻辑对应），编号100表示第一个USB合法设备，编号1表示第二个USB合法设备，以此类推。
* @n 200~299 - 表示PCSC模式（编号逻辑对应），编号200表示第一个PCSC合法设备，编号201表示第二个PCSC合法设备，以此类推。
* @n 300~399 - 表示蓝牙模式（编号逻辑对应），编号300表示第一个蓝牙合法设备，编号301表示第二个蓝牙合法设备，以此类推。
* @param[in] baud 波特率，只针对串口模式有效。
* @param[in] name 设备逻辑名称。
* @return <0表示失败，否则为设备标识符。
*/
HANDLE USER_API hs_init_name(short port, int baud, const char *name);

/**
* @brief  关闭设备。
* @par    说明：
* 关闭设备的通讯和释放资源。
* @param[in] icdev 设备标识符。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_exit(HANDLE icdev);

/**
* @brief  设备蜂鸣。
* @par    说明：
* 设备蜂鸣器发出指定时间的蜂鸣声。
* @param[in] icdev 设备标识符。
* @param[in] _Msec 蜂鸣时间，单位为10毫秒。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_beep(HANDLE icdev, unsigned short _Msec);
/**
* @brief  读取指定块的M1卡值
* @par    说明：
* @param[in] icdev 设备标识符。
* @param[in] SecNr 扇区号0-15
* @param[in] DataBlock 当前区的块号0-3
* @param[in] _NKey 秘钥
* @param[in] PwdType 模式0-6 默认0
* @param[out] rdbuf 读到的数据 16字节 32字符
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ReadM1Card_hex(HANDLE icdev, int SecNr, int DataBlock, unsigned char *_NKey, int PwdType,char  *rdbuf);
/**
* @brief  写指定块的M1卡值
* @par    说明：
* @param[in] icdev 设备标识符。
* @param[in] SecNr 扇区号0-15
* @param[in] DataBlock 当前区的块号0-3
* @param[in] _NKey 秘钥
* @param[in] PwdType 模式0-6 默认0
* @param[in] wrbuf 读到的数据 16字节 32字符
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_WriteM1Card_hex(HANDLE icdev, int SecNr, int DataBlock, unsigned char *_NKey, int PwdType,char  *wrbuf);




//M1 卡相关函数
/**
* @brief  寻卡请求、防卡冲突、选卡操作。
* @par    说明：
* 内部包含了 ::hs_request ::hs_anticoll ::hs_select ::hs_anticoll2 ::hs_select2 的功能，此接口有设计缺陷，不能返回卡序列号实际长度，建议使用 ::hs_card_n 替代。
* @param[in] icdev 设备标识符。
* @param[in] _Mode 模式，同 ::hs_request 的 @a _Mode 。
* @param[out] _Snr 返回的卡序列号，请至少分配8个字节。
* @return <0表示失败，==0表示成功，==1表示无卡或无法寻到卡片。
*/
short USER_API hs_card_double(HANDLE icdev, unsigned char _Mode, unsigned char *_Snr);

/**
* @brief  寻卡请求、防卡冲突、选卡操作。
* @par    说明：
* ::hs_card_double 的HEX形式接口，参数 @a _Snr 为HEX格式。
*/
short USER_API hs_card_double_hex(HANDLE icdev, unsigned char _Mode, unsigned char *_Snr);

/**
* @brief  装载设备密码。
* @par    说明：
* 装载M1卡密码到设备内部，装载后可以在特定时候用 ::hs_authentication 来验证M1卡密码。注意：由于多次装载设备密码可能会受硬件存储寿命限制，此接口只用于密码相对固定，装载次数少的场合。
* @param[in] icdev 设备标识符。
* @param[in] _Mode 模式，同 ::hs_authentication 的 @a _Mode 。
* @n 0x00 - 表示用设备内部装载的第0套A密码来验证当前选取卡片的A密码。
* @n 0x01 - 表示用设备内部装载的第1套A密码来验证当前选取卡片的A密码。
* @n 0x02 - 表示用设备内部装载的第2套A密码来验证当前选取卡片的A密码。
* @n 0x04 - 表示用设备内部装载的第0套B密码来验证当前选取卡片的B密码。
* @n 0x05 - 表示用设备内部装载的第1套B密码来验证当前选取卡片的B密码。
* @n 0x06 - 表示用设备内部装载的第2套B密码来验证当前选取卡片的B密码。
* @param[in] _SecNr 对应装载的扇区号。
* @param[in] _NKey 写入设备中的卡密码，固定为6个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_load_key(HANDLE icdev, unsigned char _Mode, unsigned char _SecNr, unsigned char *_NKey);

/**
* @brief  装载设备密码。
* @par    说明：
* ::hs_load_key 的HEX形式接口，参数 @a _NKey 为HEX格式。
*/
short USER_API hs_load_key_hex(HANDLE icdev, unsigned char _Mode, unsigned char _SecNr, char *_NKey);

/**
* @brief  验证M1卡密码。
* @par    说明：
* 使用设备内部装载的密码来验证M1卡密码。
* @param[in] icdev 设备标识符。
* @param[in] _Mode 模式。
* @n 0x00 - 表示用设备内部装载的第0套A密码来验证当前选取卡片的A密码。
* @n 0x01 - 表示用设备内部装载的第1套A密码来验证当前选取卡片的A密码。
* @n 0x02 - 表示用设备内部装载的第2套A密码来验证当前选取卡片的A密码。
* @n 0x04 - 表示用设备内部装载的第0套B密码来验证当前选取卡片的B密码。
* @n 0x05 - 表示用设备内部装载的第1套B密码来验证当前选取卡片的B密码。
* @n 0x06 - 表示用设备内部装载的第2套B密码来验证当前选取卡片的B密码。
* @param[in] _SecNr 要验证密码的扇区号。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_authentication(HANDLE icdev, unsigned char _Mode, unsigned char _SecNr);

/**
* @brief  读卡数据。
* @par    说明：
* 读取卡内数据，对于M1卡，一次读取一个块的数据，为16个字节；对于ML卡，一次读取相同属性的两页，为8个字节。
* @param[in] icdev 设备标识符。
* @param[in] _Adr 地址。
* @n M1卡 - S50块地址（0~63），S70块地址（0~255）。
* @n ML卡 - 页地址（0~11）。
* @param[out] _Data 固定返回16个字节数据，真实数据可能小于16个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_read(HANDLE icdev, unsigned char _Adr, unsigned char *_Data);

/**
* @brief  读卡数据。
* @par    说明：
* ::hs_read 的HEX形式接口，参数 @a _Data 为HEX格式。
*/
short USER_API hs_read_hex(HANDLE icdev, unsigned char _Adr, char *_Data);

/**
* @brief  写卡数据。
* @par    说明：
* 写入数据到卡片内，对于M1卡，一次必须写入一个块的数据，为16个字节；对于ML卡，一次必须写入一个页的数据，为4个字节。
* @param[in] icdev 设备标识符。
* @param[in] _Adr 地址。
* @n M1卡 - S50块地址（1~63），S70块地址（1~255）。
* @n ML卡 - 页地址（2~11）。
* @param[out] _Data 固定传入16个字节数据，真实数据可能小于16个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_write(HANDLE icdev, unsigned char _Adr, unsigned char *_Data);

/**
* @brief  写卡数据。
* @par    说明：
* ::hs_write 的HEX形式接口，参数 @a _Data 为HEX格式。
*/
short USER_API hs_write_hex(HANDLE icdev, unsigned char _Adr, char *_Data);

/**
* @brief  M1卡密码配置块操作。
* @par    说明：
* 修改M1卡密码配置块数据，M1卡密码配置块也就是每个扇区的最后一块，包含密码A、控制字节、密码B数据。
* @param[in] icdev 设备标识符。
* @param[in] _SecNr 扇区号。
* @param[in] _KeyA 密码A，固定为6个字节。
* @param[in] _B0 块0控制字（当一扇区有16块时，对应为块0~4的控制字），低3位（D2D1D0）对应C10、C20、C30。
* @param[in] _B1 块1控制字（当一扇区有16块时，对应为块5~9的控制字），低3位（D2D1D0）对应C11、C21、C31。
* @param[in] _B2 块2控制字（当一扇区有16块时，对应为块10~14的控制字），低3位（D2D1D0）对应C12、C22、C32。
* @param[in] _B3 块3控制字（当一扇区有16块时，对应为块15的控制字），低3位（D2D1D0）对应C13、C23、C33。
* @param[in] _Bk 保留，固定为0x00。
* @param[in] _KeyB 密码B，固定为6个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_changeb3(HANDLE icdev, unsigned char _SecNr, unsigned char *_KeyA, unsigned char _B0, unsigned char _B1, unsigned char _B2, unsigned char _B3, unsigned char _Bk, unsigned char *_KeyB);

/**
* @brief  M1卡密码配置块操作。
* @par    说明：
* ::hs_changeb3 的HEX形式接口，参数 @a _KeyA @a _KeyB 为HEX格式。
*/
short USER_API hs_changeb3_hex(HANDLE icdev, unsigned char _SecNr, const char *_KeyA, unsigned char _B0, unsigned char _B1, unsigned char _B2, unsigned char _B3, unsigned char _Bk, const char *_KeyB);
/**
**reserved
*/
short USER_API hs_getname(HANDLE icdev, char *name);
/**
**reserved
*/
short USER_API hs_getver(HANDLE icdev, unsigned char *sver);
/**
* @brief  读ID卡。
* @par    说明：
* 读取ID卡数据。
* @param[in] icdev 设备标识符。
* @param[in] times 设备超时值，单位为秒。
* @param[out] _Data 返回的数据，固定为5个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_read_idcard(HANDLE icdev, unsigned char times, unsigned char *_Data);

/**
* @brief  读取id卡。
* @par    说明：
* ::hs_read_idcard 的HEX形式接口，参数 @a _Data 为HEX格式。
*/
short USER_API hs_read_idcard_hex(HANDLE icdev, unsigned char times, unsigned char *_Data);

/**
* @brief  M1卡值块回传。
* @par    说明：
* 用于把指定的值块内容暂存，后续可以使用 ::hs_transfer 将暂存值块内容传递到另一块中，实现块与块之间数值传送。
* @param[in] icdev 设备标识符。
* @param[in] _Adr 要回传的块地址。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_restore(HANDLE icdev, unsigned char _Adr);

/**
* @brief  M1卡值块传递。
* @par    说明：
* 用于把 ::hs_restore 暂存的值块内容传递到指定块中，实现块与块之间数值传送。
* @param[in] icdev 设备标识符。
* @param[in] _Adr 要传递的块地址。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_transfer(HANDLE icdev, unsigned char _Adr);

/**
* @brief  M1卡值块加值。
* @par    说明：
* 用于操作M1卡值块，使块值增加指定数值。
* @param[in] icdev 设备标识符。
* @param[in] _Adr 块地址。
* @param[in] _Value 要增加的数值。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_increment(HANDLE icdev, unsigned char _Adr, unsigned int _Value);

/**
* @brief  M1卡值块减值。
* @par    说明：
* 用于操作M1卡值块，使块值减少指定数值。
* @param[in] icdev 设备标识符。
* @param[in] _Adr 块地址。
* @param[in] _Value 要减少的数值。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_decrement(HANDLE icdev, unsigned char _Adr, unsigned int _Value);

/**
* @brief  M1卡值块初始化。
* @par    说明：
* 用于操作M1卡，使得指定块为值块，并且初始化此值块为指定数值。
* @param[in] icdev 设备标识符。
* @param[in] _Adr 块地址。
* @param[in] _Value 初始化数值。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_initval(HANDLE icdev, unsigned char _Adr, unsigned int _Value);

/**
* @brief  M1卡值块读值。
* @par    说明：
* 用于读取M1卡值块数值。
* @param[in] icdev 设备标识符。
* @param[in] _Adr 要读取的块地址。
* @param[out] _Value 返回的数值。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_readval(HANDLE icdev, unsigned char _Adr, unsigned int *_Value);

/**
* @brief  ML卡值初始化。
* @par    说明：
* 用于操作ML卡，初始化卡内容为指定数值。
* @param[in] icdev 设备标识符。
* @param[in] _Value 初始化数值。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_initval_ml(HANDLE icdev, unsigned short _Value);

/**
* @brief  ML卡读值。
* @par    说明：
* 用于读取ML卡数值。
* @param[in] icdev 设备标识符。
* @param[out] _Value 返回的数值。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_readval_ml(HANDLE icdev, unsigned short *_Value);

/**
* @brief  ML卡减值。
* @par    说明：
* 用于操作ML卡值，使值减少指定数值。
* @param[in] icdev 设备标识符。
* @param[in] _Value 要减少的数值。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_decrement_ml(HANDLE icdev, unsigned short _Value);


/**
* @brief 获取身份证信息
* @par    说明：
* 解析中国人居民身份证文字信息，获取相应的条目。
* @param[in] icdev 设备标识符。
* @param[out] name 姓名，请至少分配64个字节。
* @param[out] sex 性别，请至少分配8个字节。
* @param[out] nation 民族，请至少分配12个字节。
* @param[out] birth_day 出生日期，请至少分配32个字节。
* @param[out] address 住址，请至少分配128个字节。
* @param[out] id_number 公民身份号码，请至少分配64个字节。
* @param[out] department 签发机关，请至少分配64个字节。
* @param[out] expire_day 证件签发日期，请至少分配36个字节。
* @param[out] bmp_name 照片路径请确保有写权限。
* @return <0表示失败，==0表示成功。
*/

short USER_API hs_GetIDInfo(HANDLE icdev, unsigned char *name, unsigned char *sex, unsigned char *nation, unsigned char *birth_day, unsigned char *address, unsigned char *id_number, unsigned char *department, unsigned char *expire_day, const char *bmp_name);



/**
* @brief  读港澳台通行证
* @par    说明：
* 读取身份证的信息。
* @param[in] icdev 设备标识符。
* @param[out] name 姓名，请至少分配64个字节。
* @param[out] sex 性别，请至少分配8个字节。
* @param[out] reserved 预留项，请至少分配12个字节。
* @param[out] birth_day 出生日期，请至少分配36个字节。
* @param[out] address 住址，请至少分配144个字节。
* @param[out] id_number 公民身份号码，请至少分配76个字节。
* @param[out] department 签发机关，请至少分配64个字节。
* @param[out] expire_start_day 证件签发日期，请至少分配36个字节。
* @param[out] expire_end_day 证件终止日期，请至少分配36个字节。
* @param[out] pass_number 通行证号码，请至少分配40个字节。
* @param[out] sign_count 签发次数，请至少分配12个字节。
* @param[out] reserved2 预留项，请至少分配16个字节。
* @param[out] type_sign 证件类型标识，请至少分配8个字节。
* @param[out] reserved3 预留项，请至少分配16个字节。




* @return <0表示失败，==0表示成功。1表示外国人居住证
*/
short USER_API hs_ReadIDInforHKMOTW(HANDLE icdev, unsigned char *name, unsigned char *sex, unsigned char *reserved, unsigned char *birth_day, unsigned char *address, unsigned char *id_number, unsigned char *department, unsigned char *expire_start_day, unsigned char *expire_end_day, unsigned char *pass_number, unsigned char *sign_count, unsigned char *reserved2, unsigned char *type_sign, unsigned char *reserved3);

/**
* @brief  读身份证。
* @par    说明：
* 读取身份证的原始信息数据。
* @param[in] icdev 设备标识符。
* @param[in] type 类型。
* @n 1 - 读取文字信息、相片信息和指纹信息。
* @n 2 - 读取追加住址信息。
* @n 3 - 读取文字信息、相片信息、指纹信息和追加住址信息。
* @param[out] text_len 返回文字信息的长度。
* @param[out] text 返回的文字信息，请至少分配256个字节。
* @param[out] photo_len 返回相片信息的长度。
* @param[out] photo 返回的相片信息，请至少分配1024个字节。
* @param[out] fingerprint_len 返回指纹信息的长度。
* @param[out] fingerprint 返回的指纹信息，请至少分配1024个字节。
* @param[out] extra_len 返回追加住址信息的长度。
* @param[out] extra 返回的追加住址信息，请至少分配70个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_SamAReadCardInfo(HANDLE icdev, int type, int *text_len, unsigned char *text, int *photo_len, unsigned char *photo, int *fingerprint_len, unsigned char *fingerprint, int *extra_len, unsigned char *extra);
/**
* @brief  解析文字信息。
* @par    说明：
* 解析中国人居民身份证文字信息，获取相应的条目。
* @param[in] icdev 设备标识符。
* @param[in] charset 获取条目将采用的字符集，0表示GBK，1表示UCS-2。
* @param[in] info_len 文字信息的长度。
* @param[in] info 文字信息。
* @param[out] name 姓名，请至少分配64个字节。
* @param[out] sex 性别，请至少分配8个字节。
* @param[out] nation 民族，请至少分配12个字节。
* @param[out] birth_day 出生日期，请至少分配36个字节。
* @param[out] address 住址，请至少分配144个字节。
* @param[out] id_number 公民身份号码，请至少分配76个字节。
* @param[out] department 签发机关，请至少分配64个字节。
* @param[out] expire_start_day 证件签发日期，请至少分配36个字节。
* @param[out] expire_end_day 证件终止日期，请至少分配36个字节。
* @param[out] reserved 预留项，请至少分配76个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ParseTextInfo(HANDLE icdev, int charset, int info_len, const unsigned char *info, unsigned char *name, unsigned char *sex, unsigned char *nation, unsigned char *birth_day, unsigned char *address, unsigned char *id_number, unsigned char *department, unsigned char *expire_start_day, unsigned char *expire_end_day, unsigned char *reserved);
/**
* @brief  解析文字信息。
* @par    说明：
* 解析港澳台居民居住证文字信息，获取相应的条目。
* @param[in] icdev 设备标识符。
* @param[in] charset 获取条目将采用的字符集，0表示GBK，1表示UCS-2。
* @param[in] info_len 文字信息的长度。
* @param[in] info 文字信息。
* @param[out] name 姓名，请至少分配64个字节。
* @param[out] sex 性别，请至少分配8个字节。
* @param[out] reserved 预留项，请至少分配12个字节。
* @param[out] birth_day 出生日期，请至少分配36个字节。
* @param[out] address 住址，请至少分配144个字节。
* @param[out] id_number 公民身份号码，请至少分配76个字节。
* @param[out] department 签发机关，请至少分配64个字节。
* @param[out] expire_start_day 证件签发日期，请至少分配36个字节。
* @param[out] expire_end_day 证件终止日期，请至少分配36个字节。
* @param[out] pass_number 通行证号码，请至少分配40个字节。
* @param[out] sign_count 签发次数，请至少分配12个字节。
* @param[out] reserved2 预留项，请至少分配16个字节。
* @param[out] type_sign 证件类型标识，请至少分配8个字节。
* @param[out] reserved3 预留项，请至少分配16个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ParseTextInfoForHkMoTw(HANDLE icdev, int charset, int info_len, const unsigned char *info, unsigned char *name, unsigned char *sex, unsigned char *reserved, unsigned char *birth_day, unsigned char *address, unsigned char *id_number, unsigned char *department, unsigned char *expire_start_day, unsigned char *expire_end_day, unsigned char *pass_number, unsigned char *sign_count, unsigned char *reserved2, unsigned char *type_sign, unsigned char *reserved3);

/**
* @brief  解析文字信息。
* @par    说明：
* 解析外国人永久居留证文字信息，获取相应的条目。
* @param[in] icdev 设备标识符。
* @param[in] charset 获取条目将采用的字符集，0表示GBK，1表示UCS-2。
* @param[in] info_len 文字信息的长度。
* @param[in] info 文字信息。
* @param[out] english_name 英文姓名，请至少分配244个字节。
* @param[out] sex 性别，请至少分配8个字节。
* @param[out] id_number 永久居留证号码，请至少分配64个字节。
* @param[out] citizenship 国籍或所在地区代码，请至少分配16个字节。
* @param[out] chinese_name 中文姓名，请至少分配64个字节。
* @param[out] expire_start_day 证件签发日期，请至少分配36个字节。
* @param[out] expire_end_day 证件终止日期，请至少分配36个字节。
* @param[out] birth_day 出生日期，请至少分配36个字节。
* @param[out] version_number 证件版本号，请至少分配12个字节。
* @param[out] department_code 当次申请受理机关代码，请至少分配20个字节。
* @param[out] type_sign 证件类型标识，请至少分配8个字节。
* @param[out] reserved 预留项，请至少分配16个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ParseTextInfoForForeigner(HANDLE icdev, int charset, int info_len, const unsigned char *info, unsigned char *english_name, unsigned char *sex, unsigned char *id_number, unsigned char *citizenship, unsigned char *chinese_name, unsigned char *expire_start_day, unsigned char *expire_end_day, unsigned char *birth_day, unsigned char *version_number, unsigned char *department_code, unsigned char *type_sign, unsigned char *reserved);

/**
* @brief  解析相片信息。
* @par    说明：
* 解析相片信息，通过公安部相片解码库还原相片图像数据。
* @param[in] icdev 设备标识符。
* @param[in] type 相片图像数据的格式，0表示BMP文件，1表示BMP缓存，2表示BMP Base64字符串。
* @param[in] info_len 相片信息的长度。
* @param[in] info 相片信息。
* @param[in,out] photo_len 数据的长度。
* @n BMP文件 - 无效。
* @n BMP缓存 - 传入 @a photo 分配的字节数，返回相片图像数据的长度。
* @n BMP Base64字符串 - 传入 @a photo 分配的字节数，返回相片图像数据Base64字符串的长度，不含'\0'。
* @param[in,out] photo 数据。
* @n BMP文件 - 传入文件名，请确保有写入的权限。
* @n BMP缓存 - 返回的相片图像数据，请至少分配65536个字节。
* @n BMP Base64字符串 - 返回的相片图像数据Base64字符串，请至少分配65536个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ParsePhotoInfo(HANDLE icdev, int type, int info_len, const unsigned char *info, int *photo_len, unsigned char *photo);

/**
* @brief  解析其它信息。
* @par    说明：
* 解析其它信息。
* @param[in] icdev 设备标识符。
* @param[in] flag 标志，0表示性别，1表示民族，2表示国籍。
* @param[in] in_info 传入信息。
* @param[out] out_info 返回的信息。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ParseOtherInfo(HANDLE icdev, int flag, const unsigned char *in_info, unsigned char *out_info);
/**
* @brief  生成身份证正面和背面图像。
* @par    说明：
* 生成身份证正面和背面图像。
* @param[in] icdev 设备标识符。
* @param[in] type 类型，0表示中国人居民身份证，1表示外国人永久居留证。
* @param[in] text_len 文字信息的长度。
* @param[in] text 文字信息。
* @param[in] photo_len 相片信息的长度。
* @param[in] photo 相片信息。
* @param[in] front_file 传入正面图像文件名，请确保有写入的权限。
* @param[in] back_file 传入背面图像文件名，请确保有写入的权限。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_IdCardImageBuild(HANDLE icdev, int type, int text_len, const unsigned char *text, int photo_len, const unsigned char *photo, const char *front_file, const char *back_file);


/**
* @brief  读身份证。
* @par    说明：
* 读取身份证模块返回的原始数据，包含基础文字和相片内容，内部会做解析并且分配资源来保存，释放资源请使用 ::hs_end_i_d 。
* @param[in] icdev 设备标识符。
* @return <0表示失败，否则为身份证标识符。
*/
HANDLE USER_API hs_start_i_d(HANDLE icdev);

/**
* @brief  读身份证。
* @par    说明：
* 读取身份证模块返回的原始数据，包含基础文字、相片、指纹内容，内部会做解析并且分配资源来保存，释放资源请使用 ::hs_end_i_d 。
* @param[in] icdev 设备标识符。
* @return <0表示失败，否则为身份证标识符。
*/
HANDLE USER_API hs_start_i_d_2(HANDLE icdev);

/**
* @brief  获取姓名。
* @par    说明：
* 获取内部保存的姓名。
* @param[in] idhandle 身份证标识符。
* @return 返回的姓名字符串。
*/
char *USER_API hs_i_d_query_name(HANDLE idhandle);

/**
* @brief  获取姓名。
* @par    说明：
* 获取内部保存的姓名。
* @param[in] idhandle 身份证标识符。
* @param[out] name 姓名，请至少分配32个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_name_2(HANDLE idhandle, char *name);

/**
* @brief  获取性别。
* @par    说明：
* 获取内部保存的性别。
* @param[in] idhandle 身份证标识符。
* @return 返回的性别字符串。
*/
char *USER_API hs_i_d_query_sex(HANDLE idhandle);

/**
* @brief  获取性别。
* @par    说明：
* 获取内部保存的性别。
* @param[in] idhandle 身份证标识符。
* @param[out] sex 性别，请至少分配8个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_sex_2(HANDLE idhandle, char *sex);

/**
* @brief  获取民族。
* @par    说明：
* 获取内部保存的民族。
* @param[in] idhandle 身份证标识符。
* @return 返回的民族字符串。
*/
char *USER_API hs_i_d_query_nation(HANDLE idhandle);

/**
* @brief  获取民族。
* @par    说明：
* 获取内部保存的民族。
* @param[in] idhandle 身份证标识符。
* @param[out] nation 民族，请至少分配32个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_nation_2(HANDLE idhandle, char *nation);

/**
* @brief  获取生日。
* @par    说明：
* 获取内部保存的生日。
* @param[in] idhandle 身份证标识符。
* @return 返回的生日字符串。
*/
char *USER_API hs_i_d_query_birth(HANDLE idhandle);

/**
* @brief  获取生日。
* @par    说明：
* 获取内部保存的生日。
* @param[in] idhandle 身份证标识符。
* @param[out] birth 生日，请至少分配16个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_birth_2(HANDLE idhandle, char *birth);

/**
* @brief  获取住址。
* @par    说明：
* 获取内部保存的住址。
* @param[in] idhandle 身份证标识符。
* @return 返回的住址字符串。
*/
char *USER_API hs_i_d_query_address(HANDLE idhandle);

/**
* @brief  获取住址。
* @par    说明：
* 获取内部保存的住址。
* @param[in] idhandle 身份证标识符。
* @param[out] address 住址，请至少分配128个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_address_2(HANDLE idhandle, char *address);

/**
* @brief  获取公民身份号码。
* @par    说明：
* 获取内部保存的公民身份号码。
* @param[in] idhandle 身份证标识符。
* @return 返回的公民身份号码字符串。
*/
char *USER_API hs_i_d_query_id_number(HANDLE idhandle);

/**
* @brief  获取公民身份号码。
* @par    说明：
* 获取内部保存的公民身份号码。
* @param[in] idhandle 身份证标识符。
* @param[out] id_number 公民身份号码，请至少分配32个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_id_number_2(HANDLE idhandle, char *id_number);

/**
* @brief  获取签发机关。
* @par    说明：
* 获取内部保存的签发机关。
* @param[in] idhandle 身份证标识符。
* @return 返回的签发机关字符串。
*/
char *USER_API hs_i_d_query_department(HANDLE idhandle);

/**
* @brief  获取签发机关。
* @par    说明：
* 获取内部保存的签发机关。
* @param[in] idhandle 身份证标识符。
* @param[out] department 签发机关，请至少分配32个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_department_2(HANDLE idhandle, char *department);

/**
* @brief  获取有效期限。
* @par    说明：
* 获取内部保存的有效期限。
* @param[in] idhandle 身份证标识符。
* @return 返回的有效期限字符串。
*/
char *USER_API hs_i_d_query_expire_day(HANDLE idhandle);

/**
* @brief  获取有效期限。
* @par    说明：
* 获取内部保存的有效期限。
* @param[in] idhandle 身份证标识符。
* @param[out] expire_day 有效期限，请至少分配32个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_expire_day_2(HANDLE idhandle, char *expire_day);

/**
* @brief  获取相片原始数据。
* @par    说明：
* 获取内部保存的相片原始数据，此数据需要通过公安部相片解码库解码才能生成相片图像。
* @param[in] idhandle 身份证标识符。
* @return 返回的相片原始数据，数据实际长度通过调用 ::hs_i_d_query_photo_len 来获取。
*/
unsigned char *USER_API hs_i_d_query_photo(HANDLE idhandle);

/**
* @brief  获取相片原始数据。
* @par    说明：
* 获取内部保存的相片原始数据，此数据需要通过公安部相片解码库解码才能生成相片图像。
* @param[in] idhandle 身份证标识符。
* @param[out] photo 相片原始数据，请至少分配4096个字节，数据实际长度通过调用 ::hs_i_d_query_photo_len 来获取。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_photo_2(HANDLE idhandle, unsigned char *photo);

/**
* @brief  获取相片原始数据长度。
* @par    说明：
* 获取内部保存的相片原始数据的长度。
* @param[in] idhandle 身份证标识符。
* @return 返回的相片原始数据长度。
*/
unsigned int USER_API hs_i_d_query_photo_len(HANDLE idhandle);

/**
* @brief  生成相片图像文件。
* @par    说明：
* 使用内部保存的相片原始数据，通过调用公安部相片解码库解码生成相片图像文件。
* @param[in] idhandle 身份证标识符。
* @param[in] FileName 文件名，请确保有写入的权限。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_photo_file(HANDLE idhandle, const char *FileName);

/**
* @brief  生成相片图像数据。
* @par    说明：
* 使用内部保存的相片原始数据，通过调用公安部相片解码库解码生成相片图像数据。
* @param[in] idhandle 身份证标识符。
* @param[out] BmpBuffer 返回的相片图像数据，请至少分配65536个字节。
* @param[in,out] BmpLength 传入 @a BmpBuffer 分配的字节数，返回相片图像数据的长度。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_photo_bmp_buffer(HANDLE idhandle, unsigned char *BmpBuffer, unsigned int *BmpLength);

/**
* @brief  获取指纹原始数据。
* @par    说明：
* 获取内部保存的指纹原始数据。
* @param[in] idhandle 身份证标识符。
* @return 返回的指纹原始数据，数据实际长度通过调用 ::hs_i_d_query_finger_len 来获取。
*/
unsigned char *USER_API hs_i_d_query_finger(HANDLE idhandle);

/**
* @brief  获取指纹原始数据。
* @par    说明：
* 获取内部保存的指纹原始数据。
* @param[in] idhandle 身份证标识符。
* @param[out] finger 指纹原始数据，请至少分配4096个字节，数据实际长度通过调用 ::hs_i_d_query_finger_len 来获取。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_i_d_query_finger_2(HANDLE idhandle, unsigned char *finger);

/**
* @brief  获取指纹原始数据长度。
* @par    说明：
* 获取内部保存的指纹原始数据的长度。
* @param[in] idhandle 身份证标识符。
* @return 返回的指纹原始数据长度。
*/
unsigned int USER_API hs_i_d_query_finger_len(HANDLE idhandle);

/**
* @brief  保留。
*/
short USER_API hs_i_d_query_finger_file(HANDLE idhandle, const char *FileName);

/**
* @brief  保留。
*/
short USER_API hs_i_d_query_finger_bmp_buffer(HANDLE idhandle, unsigned char *BmpBuffer, unsigned int *BmpLength);

/**
* @brief  释放读身份证资源。
* @par    说明：
* 释放 ::hs_start_i_d ::hs_start_i_d_2 分配的资源。
* @param[in] idhandle 身份证标识符。
*/
void USER_API hs_end_i_d(HANDLE idhandle);

/**
* @brief  获取身份证UID。
* @par    说明：
* 获取身份证的唯一标识，长度为8个字节。
* @param[in] icdev 设备标识符。
* @param[out] uid 返回的UID，固定为8个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_getuid_i_d(HANDLE icdev, unsigned char *uid);

/**
* @brief  获取银行卡帐户号码。
* @par    说明：
* 获取银行卡帐户号码。
* @param[in] icdev 设备标识符。
* @param[in] type 类型，0表示非接触式，1表示接触式。
* @param[out] number 返回的银行卡帐户号码字符串，请至少分配64个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_GetBankAccountNumber(HANDLE icdev, int type, char *number);

/**
* @brief  获取社保卡MFEF05文件内容。
* @par    说明：
* @param[in] icdev 设备标识符。
* @param[out] pincode 卡识别码,cardtype卡类型，version卡规范版本，orgnum初始化机构编号 ,starttime 发卡日期 ,endtime 有效日期,cardnum卡号。
* @return <0表示失败，==0表示成功。
*/

long USER_API hs_ReadMFEF05(HANDLE icdev,char *pincode,char *cardtype,char *version,char *orgnum,char *starttime,char *endtime,char *cardnum);
/**
* @brief  获取社保卡MFEF06文件内容。
* @par    说明：
* @param[in] icdev 设备标识符。
* @param[out] IDnum 身份证号,name 姓名,exname姓名扩展,sex性别,nation民族,addr出生地,birthday出生日期。
* @return <0表示失败，==0表示成功。
*/
long USER_API hs_ReadMFEF06(HANDLE icdev,char *IDnum,char *name,char *exname,char *sex,char *nation,char *addr,char *birthday);
/**
* @brief  获取居民健康卡EF05文件内容。
* @par    说明：
* @param[in] icdev 设备标识符。
* @param[out]version版本,orgnum机构名称,idnum 身份证号。
* @return <0表示失败，==0表示成功。
*/
long USER_API hs_ReadHSEF05(HANDLE icdev,char *version,char *orgnum,char *idnum); 
/**
* @brief  获取居民健康卡EF06文件内容。
* @par    说明：
* @param[in] icdev 设备标识符。
* @param[out] pOutInfo 返回的文件内容，请至少分配128个字节。
* @return <0表示失败，==0表示成功。
*/
long USER_API hs_ReadHSEF06(HANDLE icdev,char *pOutInfo); 

/**
* @brief  数据转换。
* @par    说明：
* 普通数据换成十六进制字符串（短转长）。
* @param[in] hex 要转换的数据。
* @param[out] a 转换后的字符串。
* @param[in] length 要转换数据的长度。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_hex_a(unsigned char *hex, unsigned char *a, short length);

/**
* @brief  数据转换。
* @par    说明：
* 十六进制字符数据转换为普通数据（长转短）。
* @param[in] a 要转换的数据。
* @param[out] hex 转换后的数据。
* @param[in] len 要转换数据的长度。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_a_hex(unsigned char *a, unsigned char *hex, short len);


/**
* @brief  设置当前接触式卡座。
* @par    说明：
* 设置当前接触式卡座为指定卡座，用于多卡座切换卡操作。
* @param[in] icdev 设备标识符。
* @param[in] _Byte 卡座编号。
* @n 0x0C - 附卡座/接触式CPU1卡座。
* @n 0x0B - 接触式CPU2卡座。
* @n 0x0D - SAM1卡座。
* @n 0x0E - SAM2卡座。
* @n 0x0F - SAM3卡座。
* @n 0x11 - SAM4卡座。
* @n 0x12 - SAM5卡座。
* @n 0x13 - SAM6卡座/ESAM芯片。
* @n 0x14 - SAM7卡座。
* @n 0x15 - SAM8卡座。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_setcpu(HANDLE icdev, unsigned char _Byte);

/**
* @brief  接触式CPU卡复位。
* @par    说明：
* 对当前卡座CPU卡进行复位操作，此复位为冷复位。
* @param[in] icdev 设备标识符。
* @param[out] rlen 返回复位信息的长度。
* @param[out] databuffer 返回的复位信息，请至少分配128个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_cpureset(HANDLE icdev, unsigned char *rlen, unsigned char *databuffer);

/**
* @brief  接触式CPU卡指令交互。
* @par    说明：
* 对当前卡座CPU卡进行指令交互操作，注意此接口不封装卡协议部分。
* @param[in] icdev 设备标识符。
* @param[in] slen 发送数据的长度。
* @param[in] sendbuffer 发送数据。
* @param[out] rlen 返回数据的长度。
* @param[out] databuffer 返回的数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_cpuapdusource(HANDLE icdev, unsigned char slen, unsigned char *sendbuffer, unsigned char *rlen, unsigned char *databuffer);

/**
* @brief  接触式CPU卡指令交互。
* @par    说明：
* 对当前卡座CPU卡进行指令交互操作，注意此接口已封装卡协议部分。
* @param[in] icdev 设备标识符。
* @param[in] slen 发送数据的长度。
* @param[in] sendbuffer 发送数据。
* @param[out] rlen 返回数据的长度。
* @param[out] databuffer 返回的数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_cpuapdu(HANDLE icdev, unsigned char slen, unsigned char *sendbuffer, unsigned char *rlen, unsigned char *databuffer);

/**
* @brief  接触式CPU卡复位。
* @par    说明：
* ::hs_cpureset 的HEX形式接口，参数 @a databuffer 为HEX格式。
*/
short USER_API hs_cpureset_hex(HANDLE icdev, unsigned char *rlen, char *databuffer);

/**
* @brief  接触式CPU卡指令交互。
* @par    说明：
* ::hs_cpuapdusource 的HEX形式接口，参数 @a sendbuffer @a databuffer 为HEX格式。
*/
short USER_API hs_cpuapdusource_hex(HANDLE icdev, unsigned char slen, char *sendbuffer, unsigned char *rlen, char *databuffer);

/**
* @brief  接触式CPU卡指令交互。
* @par    说明：
* ::hs_cpuapdu 的HEX形式接口，参数 @a sendbuffer @a databuffer 为HEX格式。
*/
short USER_API hs_cpuapdu_hex(HANDLE icdev, unsigned char slen, char *sendbuffer, unsigned char *rlen, char *databuffer);

/**
* @brief  接触式CPU卡指令交互。
* @par    说明：
* 对当前卡座CPU卡进行指令交互操作，注意此接口已封装卡协议部分，内部处理了SW1为0x61和0x6C的情况。
* @param[in] icdev 设备标识符。
* @param[in] slen 发送数据的长度。
* @param[in] sendbuffer 发送数据。
* @param[out] rlen 返回数据的长度。
* @param[out] databuffer 返回的数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_cpuapdurespon(HANDLE icdev, unsigned char slen, unsigned char *sendbuffer, unsigned char *rlen, unsigned char *databuffer);

/**
* @brief  接触式CPU卡指令交互。
* @par    说明：
* ::hs_cpuapdurespon 的HEX形式接口，参数 @a sendbuffer @a databuffer 为HEX格式。
*/
short USER_API hs_cpuapdurespon_hex(HANDLE icdev, unsigned char slen, char *sendbuffer, unsigned char *rlen, char *databuffer);
/**
* @brief  非接触式CPU卡复位。
* @par    说明：
* 对感应区CPU卡进行复位操作。
* @param[in] icdev 设备标识符。
* @param[out] rlen 返回复位信息的长度。
* @param[out] receive_data 返回的复位信息，请至少分配128个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_pro_reset(HANDLE icdev, unsigned char *rlen, unsigned char *receive_data);

/**
* @brief  非接触式CPU卡指令交互。
* @par    说明：
* 对感应区CPU卡进行指令交互操作，注意此接口已封装卡协议部分。
* @param[in] icdev 设备标识符。
* @param[in] slen 发送数据的长度。
* @param[in] sendbuffer 发送数据。
* @param[out] rlen 返回数据的长度。
* @param[out] databuffer 返回的数据。
* @param[in] timeout 超时值，此值只在部分设备的底层使用，单位为250毫秒，一般调用建议值为7。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_pro_command(HANDLE icdev, unsigned char slen, unsigned char *sendbuffer, unsigned char *rlen, unsigned char *databuffer, unsigned char timeout);

/**
* @brief  非接触式CPU卡复位。
* @par    说明：
* ::hs_pro_reset 的HEX形式接口，参数 @a receive_data 为HEX格式。
*/
short USER_API hs_pro_resethex(HANDLE icdev, unsigned char *rlen, char *receive_data);
/**
* @brief  非接触式CPU卡指令交互。
* @par    说明：
* ::hs_pro_command 的HEX形式接口，参数 @a sendbuffer @a databuffer 为HEX格式。
*/
short USER_API hs_pro_commandhex(HANDLE icdev, unsigned char slen, char *sendbuffer, unsigned char *rlen, char *databuffer, unsigned char timeout);
/**
* @brief  设置接触式CPU卡参数。
* @par    说明：
* 此接口可控制接触式CPU卡操作的行为，当不掉用时，设备将使用默认方式进行接触式CPU卡操作。
* @param[in] icdev 设备标识符。
* @param[in] cputype 卡座编号，同 ::hs_setcpu 的 @a _Byte 。
* @param[in] cpupro 卡协议编号，0x00表示T0，0x01表示T1，默认为0x00。
* @param[in] cpuetu 卡复位波特率编号，0x5C表示9600，0x14表示38400.
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_setcpupara(HANDLE icdev, unsigned char cputype, unsigned char cpupro, unsigned char cpuetu);

/**
* @brief  读身份证。
* @par    说明：
* 读取身份证的信息。
* @param[in] icdev 设备标识符。
* @param[out] name 姓名，请至少分配64个字节。
* @param[out] sex 性别，请至少分配8个字节。
* @param[out] nation 民族，请至少分配12个字节。
* @param[out] birth_day 出生日期，请至少分配36个字节。
* @param[out] address 住址，请至少分配144个字节。
* @param[out] id_number 公民身份号码，请至少分配76个字节。
* @param[out] department 签发机关，请至少分配64个字节。
* @param[out] expire_start_day 证件签发日期，请至少分配36个字节。
* @param[out] expire_end_day 证件终止日期，请至少分配36个字节。
* @param[out] photo_len
* @param[out] photo 照片信息，请至少分配1024个字节。
* @param[out] fingerprint_len
* @param[out] fingerprint 照片信息，请至少分配1024个字节。
* @param[out] reserved 预留项，请至少分配76个字节。
* @return <0表示失败，==0表示成功。1表示外国人居住证
*/
short USER_API hs_ReadIDInfor(HANDLE icdev, unsigned char *name, unsigned char *sex, unsigned char *nation, unsigned char *birth_day, unsigned char *address, unsigned char *id_number, unsigned char *department, unsigned char *expire_start_day, unsigned char *expire_end_day, int *photo_len,unsigned char *photo,int *fingerprint_len, unsigned char *fingerprint,unsigned char *reserved);
/**
* @brief  读身份证。
* @par    说明：
* 读取身份证的信息。
* @param[in] icdev 设备标识符。
* @param[out] name 姓名，请至少分配64个字节。
* @param[out] sex 性别，请至少分配8个字节。
* @param[out] nation 民族，请至少分配12个字节。
* @param[out] birth_day 出生日期，请至少分配36个字节。
* @param[out] address 住址，请至少分配144个字节。
* @param[out] id_number 公民身份号码，请至少分配76个字节。
* @param[out] department 签发机关，请至少分配64个字节。
* @param[out] expire_start_day 证件签发日期，请至少分配36个字节。
* @param[out] expire_end_day 证件终止日期，请至少分配36个字节。
* @param[out] photo_len
* @param[out] photo 照片信息，请至少分配1024个字节。
* @param[out] fingerprint_len
* @param[out] fingerprint 照片信息，请至少分配1024个字节。
* @param[out] reserved 预留项，请至少分配76个字节。
* @return <0表示失败，==0表示成功。1表示外国人居住证
*/
short USER_API hs_ReadIDInfor2(HANDLE icdev, unsigned char *name, unsigned char *sex, unsigned char *nation, unsigned char *birth_day, unsigned char *address, unsigned char *id_number, unsigned char *department, unsigned char *expire_start_day, unsigned char *expire_end_day, int *photo_len,unsigned char *photo);

/**
* @brief  读4442卡。
* @par    说明：
* 读取4442卡的数据。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 读取长度。
* @param[out] data_buffer 返回的数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_read_4442(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  读4442卡。
* @par    说明：
* ::hs_read_4442 的HEX形式接口，参数 @a data_buffer 为HEX格式。
*/
short USER_API hs_read_4442_hex(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  写4442卡。
* @par    说明：
* 写入数据到4442卡中。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 写入长度。
* @param[in] data_buffer 传入数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_write_4442(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  写4442卡。
* @par    说明：
* ::hs_write_4442 的HEX形式接口，参数 @a data_buffer 为HEX格式。
*/
short USER_API hs_write_4442_hex(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  验证4442卡密码。
* @par    说明：
* 使用传入的密码来验证4442卡密码。
* @param[in] icdev 设备标识符。
* @param[in] passwd 密码，固定为3个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_verifypin_4442(HANDLE icdev, unsigned char *passwd);

/**
* @brief  验证4442卡密码。
* @par    说明：
* ::hs_verifypin_4442 的HEX形式接口，参数 @a passwd 为HEX格式。
*/
short USER_API hs_verifypin_4442_hex(HANDLE icdev, unsigned char *passwd);

/**
* @brief  读4442卡密码。
* @par    说明：
* 读取4442卡的密码。
* @param[in] icdev 设备标识符。
* @param[out] passwd 密码，固定为3个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_readpin_4442(HANDLE icdev, unsigned char *passwd);

/**
* @brief  读4442卡密码。
* @par    说明：
* ::hs_readpin_4442 的HEX形式接口，参数 @a passwd 为HEX格式。
*/
short USER_API hs_readpin_4442_hex(HANDLE icdev, unsigned char *passwd);

/**
* @brief  读4442卡密码计数。
* @par    说明：
* 读取4442卡的密码计数，此计数值表示可以尝试验证密码的次数。
* @param[in] icdev 设备标识符。
* @return <0表示失败，否则为密码计数值。
*/
short USER_API hs_readpincount_4442(HANDLE icdev);

/**
* @brief  修改4442卡密码。
* @par    说明：
* 修改4442卡的密码。
* @param[in] icdev 设备标识符。
* @param[in] passwd 密码，固定为3个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_changepin_4442(HANDLE icdev, unsigned char *passwd);

/**
* @brief  修改4442卡密码。
* @par    说明：
* ::hs_changepin_4442 的HEX形式接口，参数 @a passwd 为HEX格式。
*/
short USER_API hs_changepin_4442_hex(HANDLE icdev, unsigned char *passwd);

/**
* @brief  读4442卡保护位。
* @par    说明：
* 读取4442卡的保护区中哪些位置已经被置保护。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 读取长度。
* @param[out] data_buffer 返回的数据，数据中含有0x00字节的位置表示已经被置保护。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_readwrotect_4442(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  读4442卡保护位。
* @par    说明：
* ::hs_readwrotect_4442 的HEX形式接口，参数 @a data_buffer 为HEX格式。
*/
short USER_API hs_readwrotect_4442_hex(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  读4442卡保护位。
* @par    说明：
* 读取4442卡的保护区中哪些位置已经被置保护。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 读取长度。
* @param[out] data_buffer 返回的数据，数据中含有0x00字节的位置表示已经被置保护。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_readprotect_4442(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  读4442卡保护位。
* @par    说明：
* ::hs_readprotect_4442 的HEX形式接口，参数 @a data_buffer 为HEX格式。
*/
short USER_API hs_readprotect_4442_hex(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  写4442卡保护位。
* @par    说明：
* 对4442卡的保护区中指定位置进行置保护。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 写入长度。
* @param[in] data_buffer 传入数据，数据中和卡内原有数据相同的字节位置将被置保护。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_writeprotect_4442(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  写4442卡保护位。
* @par    说明：
* ::hs_writeprotect_4442 的HEX形式接口，参数 @a data_buffer 为HEX格式。
*/
short USER_API hs_writeprotect_4442_hex(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  读4428卡。
* @par    说明：
* 读取4428卡的数据。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 读取长度。
* @param[out] data_buffer 返回的数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_read_4428(HANDLE icdev, short offset, short length, unsigned char *data_buffer);
/**
* @brief  复位射频。
* @par    说明：
* 复位设备的射频，可以关闭，关闭并且启动。
* @param[in] icdev 设备标识符。
* @param[in] _Msec 为0表示关闭射频，否则为复位时间，单位为10毫秒，一般调用建议值为10。
* @return <0表示失败，==0表示成功。
*/

short USER_API hs_reset(HANDLE icdev, unsigned short _Msec);

/**
* @brief  读4428卡。
* @par    说明：
* ::hs_read_4428 的HEX形式接口，参数 @a data_buffer 为HEX格式。
*/
short USER_API hs_read_4428_hex(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  写4428卡。
* @par    说明：
* 写入数据到4428卡中。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 写入长度。
* @param[in] data_buffer 传入数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_write_4428(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  写4428卡。
* @par    说明：
* ::hs_write_4428 的HEX形式接口，参数 @a data_buffer 为HEX格式。
*/
short USER_API hs_write_4428_hex(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  验证4428卡密码。
* @par    说明：
* 使用传入的密码来验证4428卡密码。
* @param[in] icdev 设备标识符。
* @param[in] passwd 密码，固定为2个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_verifypin_4428(HANDLE icdev, unsigned char *passwd);

/**
* @brief  验证4428卡密码。
* @par    说明：
* ::hs_verifypin_4428 的HEX形式接口，参数 @a passwd 为HEX格式。
*/
short USER_API hs_verifypin_4428_hex(HANDLE icdev, unsigned char *passwd);

/**
* @brief  读4428卡密码。
* @par    说明：
* 读取4428卡的密码。
* @param[in] icdev 设备标识符。
* @param[out] passwd 密码，固定为2个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_readpin_4428(HANDLE icdev, unsigned char *passwd);

/**
* @brief  读4428卡密码。
* @par    说明：
* ::hs_readpin_4428 的HEX形式接口，参数 @a passwd 为HEX格式。
*/
short USER_API hs_readpin_4428_hex(HANDLE icdev, unsigned char *passwd);

/**
* @brief  读4428卡密码计数。
* @par    说明：
* 读取4428卡的密码计数，此计数值表示可以尝试验证密码的次数。
* @param[in] icdev 设备标识符。
* @return <0表示失败，否则为密码计数值。
*/
short USER_API hs_readpincount_4428(HANDLE icdev);

/**
* @brief  修改4428卡密码。
* @par    说明：
* 修改4428卡的密码。
* @param[in] icdev 设备标识符。
* @param[in] passwd 密码，固定为2个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_changepin_4428(HANDLE icdev, unsigned char *passwd);

/**
* @brief  修改4428卡密码。
* @par    说明：
* ::hs_changepin_4428 的HEX形式接口，参数 @a passwd 为HEX格式。
*/
short USER_API hs_changepin_4428_hex(HANDLE icdev, unsigned char *passwd);

/**
* @brief  读4428卡保护位。
* @par    说明：
* 读取4428卡的保护区中哪些位置已经被置保护。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 读取长度。
* @param[out] data_buffer 返回的数据，数据中含有0x00字节的位置表示已经被置保护。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_readprotect_4428(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  读4428卡保护位。
* @par    说明：
* ::hs_readprotect_4428 的HEX形式接口，参数 @a data_buffer 为HEX格式。
*/
short USER_API hs_readprotect_4428_hex(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  写4428卡保护位。
* @par    说明：
* 对4428卡的保护区中指定位置进行置保护。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 写入长度。
* @param[in] data_buffer 传入数据，数据中和卡内原有数据相同的字节位置将被置保护。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_writeprotect_4428(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  写4428卡保护位。
* @par    说明：
* ::hs_writeprotect_4428 的HEX形式接口，参数 @a data_buffer 为HEX格式。
*/
short USER_API hs_writeprotect_4428_hex(HANDLE icdev, short offset, short length, unsigned char *data_buffer);

/**
* @brief  检测4442卡。
* @par    说明：
* 检测当前卡座中是否存在4442卡。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在，==0表示存在。
*/
short USER_API hs_Check_4442(HANDLE icdev);

/**
* @brief  检测4428卡。
* @par    说明：
* 检测当前卡座中是否存在4428卡。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在，==0表示存在。
*/
short USER_API hs_Check_4428(HANDLE icdev);

/**
* @brief  检测24C01卡。
* @par    说明：
* 检测当前卡座中是否存在24C01卡。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在，==0表示存在。
*/
short USER_API hs_Check_24C01(HANDLE icdev);

/**
* @brief  检测24C02卡。
* @par    说明：
* 检测当前卡座中是否存在24C02卡。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在，==0表示存在。
*/
short USER_API hs_Check_24C02(HANDLE icdev);

/**
* @brief  检测24C04卡。
* @par    说明：
* 检测当前卡座中是否存在24C04卡。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在，==0表示存在。
*/
short USER_API hs_Check_24C04(HANDLE icdev);

/**
* @brief  检测24C08卡。
* @par    说明：
* 检测当前卡座中是否存在24C08卡。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在，==0表示存在。
*/
short USER_API hs_Check_24C08(HANDLE icdev);

/**
* @brief  检测24C16卡。
* @par    说明：
* 检测当前卡座中是否存在24C16卡。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在，==0表示存在。
*/
short USER_API hs_Check_24C16(HANDLE icdev);

/**
* @brief  检测24C64卡。
* @par    说明：
* 检测当前卡座中是否存在24C64卡。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在，==0表示存在。
*/
short USER_API hs_Check_24C64(HANDLE icdev);

/**
* @brief  检测CPU卡。
* @par    说明：
* 检测当前卡座中是否存在CPU卡。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在，==0表示存在T=0的CPU卡，==1表示存在T=1的CPU卡。
*/
short USER_API hs_Check_CPU(HANDLE icdev);

/**
* @brief  检测卡。
* @par    说明：
* 检测当前卡座中存在的卡类型。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在。
* @n 8 - 表示存在4442卡。
* @n 9 - 表示存在4428卡。
* @n 30 - 表示存在T=0的CPU卡。
* @n 31 - 表示存在T=1的CPU卡。
* @n 21 - 表示存在24C01卡。
* @n 22 - 表示存在24C02卡。
* @n 23 - 表示存在24C04卡。
* @n 24 - 表示存在24C08卡。
* @n 25 - 表示存在24C16卡。
* @n 26 - 表示存在24C64卡。
*/
short USER_API hs_CheckCard(HANDLE icdev);
/**
* @brief  写24C系列卡。
* @par    说明：
* 写入数据到24C系列卡中，支持24C01、24C02、24C04、24C08、24C16卡。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 写入长度。
* @param[in] snd_buffer 传入数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_write_24c(HANDLE icdev, short offset, short length, unsigned char *snd_buffer);

/**
* @brief  写24C系列卡。
* @par    说明：
* ::hs_write_24c 的HEX形式接口，参数 @a snd_buffer 为HEX格式。
*/
short USER_API hs_write_24c_hex(HANDLE icdev, short offset, short length, unsigned char *snd_buffer);

/**
* @brief  写24C64系列卡。
* @par    说明：
* 写入数据到24C64系列卡中，支持24C64、24C512、24C1024卡。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 写入长度。
* @param[in] snd_buffer 传入数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_write_24c64(HANDLE icdev, short offset, short length, unsigned char *snd_buffer);

/**
* @brief  写24C64系列卡。
* @par    说明：
* ::hs_write_24c64 的HEX形式接口，参数 @a snd_buffer 为HEX格式。
*/
short USER_API hs_write_24c64_hex(HANDLE icdev, short offset, short length, unsigned char *snd_buffer);

/**
* @brief  读24C系列卡。
* @par    说明：
* 读取24C系列卡的数据，支持24C01、24C02、24C04、24C08、24C16卡。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 读取长度。
* @param[out] receive_buffer 返回的数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_read_24c(HANDLE icdev, short offset, short length, unsigned char *receive_buffer);

/**
* @brief  读24C系列卡。
* @par    说明：
* ::hs_read_24c 的HEX形式接口，参数 @a receive_buffer 为HEX格式。
*/
short USER_API hs_read_24c_hex(HANDLE icdev, short offset, short length, unsigned char *receive_buffer);

/**
* @brief  读24C64系列卡。
* @par    说明：
* 读取24C64系列卡的数据，支持24C64、24C512、24C1024卡。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移。
* @param[in] length 读取长度。
* @param[out] receive_buffer 返回的数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_read_24c64(HANDLE icdev, short offset, short length, unsigned char *receive_buffer);

/**
* @brief  读24C64系列卡。
* @par    说明：
* ::hs_read_24c64 的HEX形式接口，参数 @a receive_buffer 为HEX格式。
*/
short USER_API hs_read_24c64_hex(HANDLE icdev, short offset, short length, unsigned char *receive_buffer);

/**
* @brief  寻卡请求、防卡冲突、选卡操作。
* @par    说明：
* 内部包含了 ::hs_request ::hs_anticoll ::hs_select 的功能。
* @param[in] icdev 设备标识符。
* @param[in] _Mode 模式，同 ::hs_request 的 @a _Mode 。
* @param[out] Strsnr 返回的卡序列号，格式为数字字符串。
* @return <0表示失败，==0表示成功，==1表示无卡或无法寻到卡片。
*/
short USER_API hs_cardstr(HANDLE icdev, unsigned char _Mode, char *Strsnr);

/**
* @brief  寻Type A或Type B卡并激活。
* @par    说明：
* 对Type A或Type B卡进行寻卡和激活。
* @param[in] icdev 设备标识符。
* @param[out] rlen 返回激活信息的长度。
* @param[out] rbuf 返回的激活信息，请至少分配128个字节。
* @param[out] type 类型，'A'表示Type A卡，'B'表示Type B卡。
* @return <0表示失败，==0表示成功，==1表示无卡或无法寻到卡片。
*/
short USER_API hs_cardAB(HANDLE icdev, unsigned char *rlen, unsigned char *rbuf, unsigned char *type);

/**
* @brief  寻Type B卡并激活。
* @par    说明：
* 对Type B卡进行寻卡和激活。
* @param[in] icdev 设备标识符。
* @param[out] rbuf 返回的激活信息，请至少分配128个字节。
* @return <0表示失败，==0表示成功，==1表示无卡或无法寻到卡片。
*/
short USER_API hs_card_b(HANDLE icdev, unsigned char *rbuf);

/**
* @brief  寻Type B卡并激活。
* @par    说明：
* ::hs_card_b 的HEX形式接口，参数 @a rbuf 为HEX格式。
*/
short USER_API hs_card_b_hex(HANDLE icdev, char *rbuf);
/**
* @brief  指示灯点亮/熄灭。
* @par    说明：
* 点亮/熄灭设备的指示灯。
* @param[in] icdev 设备标识符。
* @param[in] cled 指示灯编号，0表示全部指示灯，1表示第一个指示灯，2表示第二个指示灯，以此类推。
* @param[in] cflag 0-点亮，1-熄灭。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_led_T8(HANDLE icdev, unsigned char cled, unsigned char cflag);
/**
* @brief  读/写射频寄存器。
* @par    说明：
* 从射频寄存器读取值或写入值到射频寄存器中。
* @param[in] icdev 设备标识符。
* @param[in] flag 读写标记，0x00表示读，0x01表示写。
* @param[in] _Adr 寄存器地址。
* @param[in,out] _Data 寄存器值，固定为1个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_rw_rfreg(HANDLE icdev, unsigned char flag, unsigned char _Adr, unsigned char *_Data);

/**
* @brief  读/写射频寄存器。
* @par    说明：
* ::hs_rw_rfreg 的HEX形式接口，参数 @a _Data 为HEX格式。
*/
short USER_API hs_rw_rfreg_hex(HANDLE icdev, unsigned char flag, unsigned char _Adr, unsigned char *_Data);

/**
* @brief  检测多卡状态。
* @par    说明：
* 检测设备中存在什么类型的卡片，支持磁卡、非接、接触、身份证。
* @param[in] icdev 设备标识符。
* @param[out] flag 状态标记，固定为2个字节，可以解析为一个无符号整数（Big-Endian），值为下面列出的一种或多种之和。
* @n 0x0001 - 表示已刷磁卡。
* @n 0x0002 - 表示卡座存在接触式CPU卡。
* @n 0x0004 - 表示卡座存在接触式未知卡。
* @n 0x0008 - 表示感应区存在身份证。
* @n 0x0010 - 表示感应区存在激活前的Type A CPU卡或Type B CPU卡。
* @n 0x0020 - 表示感应区存在激活后的Type A CPU卡或Type B CPU卡。
* @n 0x0040 - 表示感应区存在激活前的M1卡。
* @n 0x0100 - 表示感应区存在激活前的多张Type A CPU卡。
* @n 0x0200 - 表示感应区存在激活前的多张M1卡。
* @n 0x0400 - 表示感应区同时存在激活前的Type A CPU卡和M1卡。
* @n 0x0800 - 表示刷磁卡失败。
* @n 0x1000 - 表示启动刷磁卡模式处于关闭状态。
* @n 0x2000 - 表示启动刷磁卡模式处于开启状态。
* @n 0x4000 - 表示感应区身份证激活前后状态一致。
* @return <0表示失败，==0表示成功，==1表示无卡或无法寻到卡片。
*/
short USER_API hs_card_exist(HANDLE icdev, unsigned char *flag);
/**
* @brief  寻卡请求、防卡冲突、选卡操作。可支持UtralLight卡
* @par    说明：
* 内部包含了 ::hs_request ::hs_anticoll ::hs_select ::hs_anticoll2 ::hs_select2 的功能。
* @param[in] icdev 设备标识符。
* @param[in] _Mode 模式，同 ::hs_request 的 @a _Mode 。
* @param[out] SnrLen 返回卡序列号的长度。
* @param[out] _Snr 返回的卡序列号，请至少分配8个字节。
* @return <0表示失败，==0表示成功，==1表示无卡或无法寻到卡片。
*/
short USER_API hs_card_n(HANDLE icdev, unsigned char _Mode, unsigned int *SnrLen, unsigned char *_Snr);
/**
* @brief  寻卡请求、防卡冲突、选卡操作。
* @par    说明：
* ::hs_card_n 的HEX形式接口，参数 @a _Snr 为HEX格式。
*/
short USER_API hs_card_n_hex(HANDLE icdev, unsigned char _Mode, unsigned int *SnrLen, unsigned char *_Snr);

/**
* @brief  查找身份证。
* @par    说明：
* 以寻卡方式查找是否有身份证存在于感应区。
* @param[in] icdev 设备标识符。
* @return <0表示失败或不存在，==0表示存在。
*/
short USER_API hs_find_i_d_speed(HANDLE icdev);

/**
* @brief  获取非接触卡类型。
* @par    说明：
* 获取感应区中存在的非接触卡类型。
* @param[in] icdev 设备标识符。
* @return <0表示失败。
* @n 0x00 - 无卡。
* @n 0x11 - Type A CPU Card。
* @n 0x13 - Type A Mifare S50。
* @n 0x14 - Type A Mifare S70。
* @n 0x15 - Type A Mifare Ultralight。
* @n 0x21 - Type B CPU Card。
* @n 0x22 - Type B 存储卡。
*/
short USER_API hs_RfGetCardType(HANDLE icdev);

/**
* @brief  读Flash。
* @par    说明：
* 读取设备内部Flash中的数据，可以用作数据保存等。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移地址。
* @param[in] length 读取长度。
* @param[out] data_buffer 返回的数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ReadFlash(HANDLE icdev, int offset, int length, unsigned char *data_buffer);

/**
* @brief  写Flash。
* @par    说明：
* 写入数据到设备内部Flash中，可以用作数据保存等。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移地址。
* @param[in] length 写入长度。
* @param[in] data_buffer 传入数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_WriteFlash(HANDLE icdev, int offset, int length, const unsigned char *data_buffer);
/**
* @brief  读取ATS数据。
* @par    说明：
* 读取Type A、Type B卡的ATS，此接口必须在卡片激活后才可使用。
* @param[in] icdev 设备标识符。
* @param[out] ats_len 返回ATS数据的长度。
* @param[out] ats 返回的ATS数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ReadRfTypeABATS(HANDLE icdev, int *ats_len, unsigned char *ats);

/**
* @brief  读取ATS数据。
* @par    说明：
* ::hs_ReadRfTypeABATS 的HEX形式接口，参数 @a ats 为HEX格式。
*/
short USER_API hs_ReadRfTypeABATS_hex(HANDLE icdev, int *ats_len, char *ats);

/**
* @brief  设备蜂鸣。
* @par    说明：
* 设备蜂鸣器按照指定参数进行蜂鸣，接口本身会直接返回，而不会等待蜂鸣器工作完成。
* @param[in] icdev 设备标识符。
* @param[in] beep_time_ms 单次蜂鸣时间，单位为毫秒。
* @param[in] interval_time_ms 间隔时间，单位为毫秒。
* @param[in] count 蜂鸣次数，其中0x0000表示停止，0xFFFF表示无限次。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_BuzzerBeep(HANDLE icdev, unsigned short beep_time_ms, unsigned short interval_time_ms, unsigned short count);
/**
* @brief  获取设备唯一识别码。
* @par    说明：
* 获取设备内部写入的唯一识别码。
* @param[in] icdev 设备标识符。
* @param[out] uid 返回的唯一识别码字符串，请至少分配33个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_GetDeviceUid(HANDLE icdev, char *uid);

/**
* @brief  获取设备商户号。
* @par    说明：
* 获取设备内部写入的商户号。
* @param[in] icdev 设备标识符。
* @param[out] number 返回的商户号字符串，请至少分配33个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_GetDeviceTradeNumber(HANDLE icdev, char *number);

/**
* @brief  获取设备终端号。
* @par    说明：
* 获取设备内部写入的终端号。
* @param[in] icdev 设备标识符。
* @param[out] number 返回的终端号字符串，请至少分配33个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_GetDeviceTerminalNumber(HANDLE icdev, char *number);

/**
* @brief  读取设备自定义信息。
* @par    说明：
* 读取设备自定义信息。
* @param[in] icdev 设备标识符。
* @param[out] info 返回的信息，固定为8个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ReadDeviceCustomInfo(HANDLE icdev, unsigned char *info);

/**
* @brief  写入设备自定义信息。
* @par    说明：
* 写入设备自定义信息。
* @param[in] icdev 设备标识符。
* @param[in] info 传入信息，固定为8个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_WriteDeviceCustomInfo(HANDLE icdev, const unsigned char *info);

/**
* @brief  读取设备型号名称。
* @par    说明：
* 读取设备型号名称。
* @param[in] icdev 设备标识符。
* @param[out] name 返回的型号名称字符串，请至少分配33个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ReadDeviceTypeName(HANDLE icdev, char *name);

/**
* @brief  写入设备型号名称。
* @par    说明：
* 写入设备型号名称。
* @param[in] icdev 设备标识符。
* @param[in] name 传入型号名称，数据格式为'\0'结尾的字符串。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_WriteDeviceTypeName(HANDLE icdev, const char *name);


/**
* @brief  寻FM11RF005卡。
* @par    说明：
* 对FM11RF005卡进行寻卡操作。
* @param[in] icdev 设备标识符。
* @param[in] _Mode 模式，模式，同 ::hs_request 的 @a _Mode 。
* @param[out] _Snr 返回的卡序列号。
* @return <0表示失败，==0表示成功，==1表示无卡或无法寻到卡片。
*/
short USER_API hs_card_fm11rf005(HANDLE icdev, unsigned char _Mode, unsigned int *_Snr);

/**
* @brief  获取FM11RF005卡序列号。
* @par    说明：
* 获取FM11RF005卡序列号。
* @param[in] icdev 设备标识符。
* @param[out] _Snr 返回的卡序列号。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_getsnr_fm11rf005(HANDLE icdev, unsigned int *_Snr);
/**
* @brief  获取FM11RF005卡序列号。
* @par    说明：
* ::hs_getsnr_fm11rf005 的HEX形式接口，参数 @a snrstr 为HEX格式。
*/
short USER_API hs_getsnr_fm11rf005_hex(HANDLE icdev, unsigned char *snrstr);



/**
* @brief  读FM11RF005卡。
* @par    说明：
* 读取FM11RF005卡的数据。
* @param[in] icdev 设备标识符。
* @param[in] _Adr 块地址（0~15）。
* @param[out] _Data 返回的数据，固定为4个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_read_fm11rf005(HANDLE icdev, unsigned char _Adr, unsigned char *_Data);

/**
* @brief  读FM11RF005卡。
* @par    说明：
* ::hs_read_fm11rf005 的HEX形式接口，参数 @a _Data 为HEX格式。
*/
short USER_API hs_read_fm11rf005_hex(HANDLE icdev, unsigned char _Adr, char *_Data);

/**
* @brief  写FM11RF005卡。
* @par    说明：
* ::hs_write_fm11rf005 的HEX形式接口，参数 @a _Data 为HEX格式。
*/
short USER_API hs_write_fm11rf005_hex(HANDLE icdev, unsigned char _Adr, char *_Data);

/**
* @brief  写FM11RF005卡。
* @par    说明：
* 写入数据到FM11RF005卡中。
* @param[in] icdev 设备标识符。
* @param[in] _Adr 块地址（2~15）。
* @param[in] _Data 传入数据，固定为4个字节。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_write_fm11rf005(HANDLE icdev, unsigned char _Adr, unsigned char *_Data);



/**
* @brief  读EEPROM。
* @par    说明：
* 读取设备内部EEPROM中的数据，可以用作数据保存等。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移地址。
* @param[in] length 读取长度。
* @param[out] rec_buffer 返回的数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_srd_eeprom(HANDLE icdev, short offset, short length, unsigned char *rec_buffer);

/**
* @brief  写EEPROM。
* @par    说明：
* 写入数据到设备内部EEPROM中，可以用作数据保存等。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移地址。
* @param[in] length 写入长度。
* @param[in] send_buffer 传入数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_swr_eeprom(HANDLE icdev, short offset, short length, unsigned char *send_buffer);

/**
* @brief  写EEPROM。
* @par    说明：
* 同 ::hs_swr_eeprom 。
*/
short USER_API hs_swr_alleeprom(HANDLE icdev, short offset, short length, unsigned char *snd_buffer);

/**
* @brief  读EEPROM。
* @par    说明：
* 同 ::hs_srd_eeprom 。
*/
short USER_API hs_srd_alleeprom(HANDLE icdev, short offset, short length, unsigned char *receive_buffer);

/**
* @brief  读EEPROM。
* @par    说明：
* ::hs_srd_eeprom 的HEX形式接口，参数 @a rec_buffer 为HEX格式。
*/
short USER_API hs_srd_eepromhex(HANDLE icdev, short offset, short length, unsigned char *rec_buffer);

/**
* @brief  写EEPROM。
* @par    说明：
* ::hs_swr_eeprom 的HEX形式接口，参数 @a send_buffer 为HEX格式。
*/
short USER_API hs_swr_eepromhex(HANDLE icdev, short offset, short length, unsigned char *send_buffer);
/**
* @brief  读外部EEPROM。
* @par    说明：
* 读取设备外部EEPROM中的数据，可以用作数据保存等。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移地址。
* @param[in] length 读取长度。
* @param[out] data_buffer 返回的数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ReadOutEeprom(HANDLE icdev, int offset, int length, unsigned char *data_buffer);

/**
* @brief  写外部EEPROM。
* @par    说明：
* 写入数据到设备外部EEPROM中，可以用作数据保存等。
* @param[in] icdev 设备标识符。
* @param[in] offset 偏移地址。
* @param[in] length 写入长度。
* @param[in] data_buffer 传入数据。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_WriteOutEeprom(HANDLE icdev, int offset, int length, const unsigned char *data_buffer);

/**
* @brief  非接触式CPU卡指令交互。
* @par    说明：
* 对感应区CPU卡进行指令交互操作，注意此接口已封装卡协议部分。
* @param[in] icdev 设备标识符。
* @param[in] slen 发送数据的长度。
* @param[in] sendbuffer 发送数据。
* @param[out] rlen 返回数据的长度。
* @param[out] databuffer 返回的数据。
* @param[in] timeout 超时值，此值只在部分设备的底层使用，单位为250毫秒，一般调用建议值为7。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_pro_commandlinkInt(HANDLE icdev, unsigned int slen, unsigned char *sendbuffer, unsigned int *rlen, unsigned char *databuffer, unsigned char timeout);

/**
* @brief  非接触式CPU卡指令交互。
* @par    说明：
* ::hs_pro_commandlinkInt 的HEX形式接口，参数 @a sendbuffer @a databuffer 为HEX格式。
*/
short USER_API hs_pro_commandlinkInt_hex(HANDLE icdev, unsigned int slen, char *sendbuffer, unsigned int *rlen, char *databuffer, unsigned char timeout);

/**
* @brief  配置非接触卡类型。
* @par    说明：
* 配置需要操作什么类型的非接触式卡，设备上电后默认操作Type A卡，可以使用此接口来改变类型，一般在寻卡前调用此接口。
* @param[in] icdev 设备标识符。
* @param[in] cardtype 类型，'A'表示Type A卡，'B'表示Type B卡。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_config_card(HANDLE icdev, unsigned char cardtype);
/**
* @brief  指示灯控制。
* @par    说明：
* 控制设备的指示灯。
* @param[in] icdev 设备标识符。
* @param[in] cLed 指示灯编号，0表示全部指示灯，1表示第一个指示灯，2表示第二个指示灯，以此类推。
* @param[in] cOpenFlag 0-点亮，1-熄灭，2-闪烁。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_ctlled(HANDLE icdev, unsigned char cLed, unsigned char cOpenFlag);


/**
* @brief  读磁条卡。
* @par    说明：
* 读取磁条卡的数据，支持1、2、3轨道。
* @param[in] icdev 设备标识符。
* @param[in] ctime 设备超时值，单位为秒。
* @param[out] pTrack1Data 返回的1轨道数据，数据格式为'\0'结尾的字符串。
* @param[out] pTrack1Len 返回1轨道数据的长度，不含'\0'。
* @param[out] pTrack2Data 返回的2轨道数据，数据格式为'\0'结尾的字符串。
* @param[out] pTrack2Len 返回2轨道数据的长度，不含'\0'。
* @param[out] pTrack3Data 返回的3轨道数据，数据格式为'\0'结尾的字符串。
* @param[out] pTrack3Len 返回3轨道数据的长度，不含'\0'。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_readmagcardall(HANDLE icdev, unsigned char ctime, unsigned char *pTrack1Data, unsigned int *pTrack1Len, unsigned char *pTrack2Data, unsigned int *pTrack2Len, unsigned char *pTrack3Data, unsigned int *pTrack3Len);


/**
* @brief  接触式CPU卡下电。
* @par    说明：
* 对当前卡座CPU卡进行下电操作。
* @param[in] icdev 设备标识符。
* @return <0表示失败，==0表示成功。
*/
short USER_API hs_cpudown(HANDLE icdev);

  /**
   * @brief  卡下电。
   * @par    说明：
   * 对指定卡座的卡片进行下电操作。
   * @param[in] icdev 设备标识符。
   * @param[in] icc_slot_no 卡座编号，用户卡为0x0n，SAM卡为0x1n，其中“n”的取值范围为1~F。
   * @return <0表示失败，==0表示成功。
   * @n -1 - 卡片类型不对。
   * @n -2 - 无卡。
   * @n -3 - 有卡未上电。
   * @n -4 - 卡片无应答。
   */
short USER_API hs_rf_poweroff(HANDLE icdev, unsigned char icc_slot_no);







#ifdef __cplusplus
}
#endif
#endif
